/**
 * ISO date string (`2021-10-15T15:42:43.083Z`)
 */
export type DateIsoString = `${number}-${number}-${number}T${number}:${number}:${number}.${number}Z`;
export declare const now: () => string;
/**
 * Formats a date as a human-readable string.
 *
 * Options:
 * - If `relative` is true, returns a relative time string like:
 *   - 'just now' (within 60 seconds)
 *   - '4 days ago', 'in 2 hours', etc.
 * - If `relative` is false or omitted:
 *   - Dates from the current year are formatted as 'MMM dd' (e.g., 'Apr 16')
 *   - Dates from other years are formatted as 'MMM dd, yyyy' (e.g., 'Oct 24, 2024')
 *   - If `includeTime` is true, the time is appended (e.g., 'Apr 16 at 03:45 PM')
 *
 * If `prefix` is provided, it will be prepended to the result (e.g., 'Updated Apr 16').
 *
 * If the provided date is invalid, logs an error and returns null.
 *
 * @param date - The date to format
 * @param relative - Whether to format the date as a relative time string
 * @param includeTime - Whether to include time in the formatted date
 * @param prefix - Optional prefix to prepend to the output string
 *
 * @example
 * formatDate({ date: new Date('2025-04-16') }) // 'Apr 16'
 * formatDate({ date: new Date('2024-10-24') }) // 'Oct 24, 2024'
 * formatDate({ date: new Date(), relative: true }) // 'just now'
 * formatDate({ date: new Date(), prefix: 'Updated', relative: true }) // 'Updated just now'
 */
export declare function formatDate({ date, relative, includeTime, prefix, }: {
    date: Date;
    relative?: boolean;
    includeTime?: boolean;
    prefix?: string;
}): string | null;
/** Get the ISO date string (`2021-10-15T15:42:43.083Z`) for right now */
export declare const nowInIsoDate: () => string;
export declare const yesterdayInIsoDate: () => string;
export declare function sortDateAsc(a: {
    date: string;
}, b: {
    date: string;
}): number;
export declare function sortDateDesc(a: {
    date: string;
}, b: {
    date: string;
}): number;
export declare const minutesFromNowInIsoDate: (minutes: number) => string;
/**
 * Converts hours, minutes, and seconds to milliseconds
 * @param h - hours (optional)
 * @param m - minutes (optional)
 * @param s - seconds (optional)
 * @returns total milliseconds
 */
export declare function toMilliseconds({ hours, minutes, seconds, }: {
    hours?: number;
    minutes?: number;
    seconds?: number;
}): number;
//# sourceMappingURL=dates.d.ts.map